@@ -71,10 +71,12 @@ pub(super) fn fetch_option_markets() -> Result<Vec<Market>> {
                 exchange: "binance".to_string(),
                 market_type: MarketType::EuropeanOption,
                 symbol: m.symbol.clone(),
-                base: base_currency.to_string(),
-                quote: m.quoteAsset.clone(),
                 base_id: base_currency.to_string(),
                 quote_id: m.quoteAsset.clone(),
+                settle_id: Some(m.quoteAsset.clone()),
+                base: base_currency.to_string(),
+                quote: m.quoteAsset.clone(),
+                settle: Some(m.quoteAsset.clone()),
                 active: true,
                 margin: true,
                 // see https://www.binance.com/en/fee/optionFee
