@@ -37,7 +37,8 @@ pub(super) fn http_get(url: &str, params: Option<&HashMap<String, String>>) -> R
     }
 }
 
-pub(super) fn precision_from_string(s: &str) -> i64 {
+#[allow(dead_code)]
+fn precision_from_string(s: &str) -> i64 {
     if let Some(dot_pos) = s.find('.') {
         let mut none_zero = 0;
         for (i, ch) in s.chars().rev().enumerate() {
